<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="2.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                              xmlns:ox="http://www.oxygenxml.com/ns/doc/schema-internal"
                              exclude-result-prefixes="ox">

  <xsl:output method="xml" indent="yes"/>

  <xsl:key name="component-by-schema" match="ox:element | ox:complexType | ox:elementGroup | ox:attribute | ox:attributeGroup"
           use="ox:schemaLocation"/>

  <xsl:key name="component-by-id" match="ox:complexType | ox:elementGroup | ox:attributeGroup"
           use="@id"/>

  <xsl:template match="/">
    <schemas>
      <xsl:for-each select="ox:schemaDoc/ox:schema">
        <schema name="{ox:qname}" location="{ox:schemaLocation}" namespace="{ox:namespace}">
          <xsl:apply-templates select="key('component-by-schema', ox:schemaLocation)"/>
        </schema>
      </xsl:for-each>
    </schemas>
  </xsl:template>

  <xsl:template match="ox:element | ox:complexType | ox:elementGroup | ox:attribute | ox:attributeGroup">
    <component id="{@id}">
      <xsl:attribute name="type">
        <xsl:choose>
          <xsl:when test="name() = 'element'">
            <xsl:value-of select="'element'"/>
          </xsl:when>
          <xsl:when test="name() = 'attribute'">
            <xsl:value-of select="'attribute'"/>
          </xsl:when>
          <xsl:when test="name() = 'complexType'">
            <xsl:value-of select="'complexType'"/>
          </xsl:when>
          <xsl:when test="name() = 'simpleType'">
            <xsl:value-of select="'simpleType'"/>
          </xsl:when>
          <xsl:when test="name() = 'elementGroup'">
            <xsl:value-of select="'group'"/>
          </xsl:when>
          <xsl:when test="name() = 'attributeGroup'">
            <xsl:value-of select="'attributeGroup'"/>
          </xsl:when>
        </xsl:choose>
      </xsl:attribute>

      <xsl:choose>
        <xsl:when test="count(ox:declarationPath) != 0">
          <xsl:attribute name="path">
            <xsl:value-of select="ox:declarationPath/ox:ref" separator="/"/>
            <xsl:text>/</xsl:text>
            <xsl:value-of select="ox:qname"/>
          </xsl:attribute>
          <xsl:attribute name="pathRootType">
            <xsl:variable name="refType" select="ox:declarationPath/ox:ref[position() = 1]/@refType"/>
            <xsl:choose>
              <xsl:when test="$refType = 'Element'">
                <xsl:value-of select="'element'"/>
              </xsl:when>
              <xsl:when test="$refType = 'Complex_Type'">
                <xsl:value-of select="'complexType'"/>
              </xsl:when>
              <xsl:when test="$refType = 'Element_Group'">
                <xsl:value-of select="'group'"/>
              </xsl:when>
              <xsl:when test="$refType = 'Attribute_Group'">
                <xsl:value-of select="'attributeGroup'"/>
              </xsl:when>
            </xsl:choose>
          </xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="path" select="ox:qname"/>
        </xsl:otherwise>
      </xsl:choose>

      <xsl:if test="count(ox:redefinedComponent) != 0">
        <xsl:attribute name="redefinition">
          <xsl:call-template name="redefinition">
            <xsl:with-param name="depth" select="0"/>
          </xsl:call-template>
        </xsl:attribute>
      </xsl:if>

      <xsl:for-each select="ox:schemaDoc/ox:schema">
        <schema name="{ox:qname}" location="{ox:schemaLocation}" namespace="{ox:namespace}">
          <xsl:apply-templates select="key('component-by-schema', ox:schemaLocation)"/>
        </schema>
      </xsl:for-each>

      <xsl:apply-templates select="ox:diagram"/>
    </component>
  </xsl:template>

  <xsl:template match="ox:diagram">
    <diagram file="{ox:location}">
       <xsl:for-each select="ox:map/ox:area">
         <area coords="{@coords}" compID="{substring-after(@href, '#')}"/>
       </xsl:for-each>
    </diagram>
  </xsl:template>

  <xsl:template name="redefinition">
    <xsl:param name="depth"/>
    <xsl:choose>
      <xsl:when test="count(ox:redefinedComponent) != 0">
        <xsl:for-each select="key('component-by-id', ox:redefinedComponent/@refId)">
          <xsl:call-template name="redefinition">
            <xsl:with-param name="depth" select="$depth + 1"/>
          </xsl:call-template>
        </xsl:for-each>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$depth - 1"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

</xsl:stylesheet>
